@@ -410,7 +410,7 @@ def internal_Library(module_name):
             if os.path.splitext(os.path.basename(srcs))[0] == module_name:  # same distribution
                 _,_,cpp = precompile(os.path.join(src_path, srcs), f"__temp__{srcs}")
                 compile(f"__temp__{srcs}", os.path.join(lib_path,module_name)+f".{outext}", "-O2", "-std=c++14",
-                f"-I{src_path}", cpp = cpp)
+                f"-I{src_path}", *FLAG, cpp = cpp)
                 os.remove(f"__temp__{srcs}")
                 return ctypes.CDLL(pkg_resources.resource_filename("uos_statphys",os.path.join("lib",f"{module_name}.{outext}")))
         raise ModuleNotFoundError()
